@@ -56,5 +56,42 @@ namespace tut
     {
     }
   }
+
+  /**
+   * Checks ensure with various "constructed" messages 
+   */
+  template<>
+  template<>
+  void object::test<3>()
+  {
+    const char* ok1 = "OK";
+    ensure(ok1,1==1);
+  }
+
+  template<>
+  template<>
+  void object::test<4>()
+  {
+
+    char* ok2 = "OK";
+    ensure(ok2,1==1);
+  }
+
+  template<>
+  template<>
+  void object::test<5>()
+  {
+    std::string msg = "OK";
+    ensure(msg,1==1);
+  }
+
+  template<>
+  template<>
+  void object::test<6>()
+  {
+    std::ostringstream oss;
+    oss << "OK";
+    ensure(oss.str(),1==1);
+  }
 }
 
